
# RABDAM
# Copyright (C) 2020 Garman Group, University of Oxford

# This file is part of RABDAM.

# RABDAM is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as
# published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.

# RABDAM is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.

# You should have received a copy of the GNU Lesser General
# Public License along with this program.  If not, see
# <http://www.gnu.org/licenses/>.

# The three letter codes of the nucleic acid and amino acid components in the
# PDB as of 23rd November 2020, taken from http://www.wwpdb.org/data/ccd


def nuc_acid_codes():
    na_codes = ['02I',
                '0A',
                '0AD',
                '0AM',
                '0AP',
                '0AU',
                '0AV',
                '0C',
                '0DA',
                '0DC',
                '0DG',
                '0DT',
                '0G',
                '0KZ',
                '0R8',
                '0SP',
                '0U',
                '0U1',
                '0UH',
                '10C',
                '125',
                '126',
                '127',
                '128',
                '12A',
                '18M',
                '18Q',
                '1AP',
                '1CC',
                '1DP',
                '1FC',
                '1MA',
                '1MG',
                '1PR',
                '1RN',
                '1SC',
                '1TL',
                '1TW',
                '1W5',
                '1WA',
                '1YH',
                '23G',
                '2AR',
                '2AT',
                '2AU',
                '2BD',
                '2BT',
                '2BU',
                '2DA',
                '2DF',
                '2DM',
                '2DT',
                '2EG',
                '2FE',
                '2FI',
                '2GF',
                '2GT',
                '2IA',
                '2JU',
                '2JV',
                '2L8',
                '2LA',
                '2LF',
                '2MA',
                '2MG',
                '2MU',
                '2NT',
                '2OM',
                '2OT',
                '2PR',
                '2SA',
                '2SG',
                '2ST',
                '31H',
                '31M',
                '3AU',
                '3DA',
                '3DR',
                '3ME',
                '3MU',
                '3TD',
                '3ZO',
                '45A',
                '47C',
                '4AC',
                '4DU',
                '4E9',
                '4EN',
                '4MF',
                '4OC',
                '4PC',
                '4PD',
                '4PE',
                '4SC',
                '4SU',
                '4TA',
                '4U3',
                '50L',
                '50N',
                '56B',
                '574',
                '5AA',
                '5AT',
                '5BU',
                '5CF',
                '5CG',
                '5CM',
                '5DB',
                '5FA',
                '5FC',
                '5FU',
                '5HC',
                '5HM',
                '5HT',
                '5HU',
                '5IC',
                '5IU',
                '5JO',
                '5MC',
                '5MU',
                '5NC',
                '5OC',
                '5PC',
                '5PY',
                '5SE',
                '5UA',
                '63G',
                '63H',
                '64P',
                '64T',
                '68Z',
                '6F7',
                '6FC',
                '6FK',
                '6FM',
                '6FU',
                '6HA',
                '6HB',
                '6HC',
                '6HG',
                '6HT',
                '6IA',
                '6MA',
                '6MC',
                '6MI',
                '6MT',
                '6MZ',
                '6NW',
                '6OG',
                '6OO',
                '6OP',
                '6PO',
                '70U',
                '73W',
                '75B',
                '77Y',
                '7AT',
                '7BG',
                '7CC',
                '7DA',
                '7GU',
                '7MG',
                '85Y',
                '8AA',
                '8AG',
                '8AN',
                '8AZ',
                '8BA',
                '8DT',
                '8FG',
                '8MG',
                '8OG',
                '8OS',
                '8PY',
                '8RJ',
                '8RO',
                '8XA',
                '8XC',
                '8XG',
                '8XU',
                '8YN',
                '92F',
                '93D',
                '94O',
                '9O4',
                '9O7',
                '9QV',
                '9V9',
                'A',
                'A1P',
                'A23',
                'A2L',
                'A2M',
                'A34',
                'A35',
                'A38',
                'A39',
                'A3A',
                'A3P',
                'A40',
                'A43',
                'A44',
                'A47',
                'A5L',
                'A5O',
                'A6A',
                'A6C',
                'A6G',
                'A6U',
                'A7C',
                'A7E',
                'A9Z',
                'AAB',
                'ABR',
                'ABS',
                'ABT',
                'AD2',
                'ADX',
                'AET',
                'AF2',
                'AFG',
                'AG9',
                'AP7',
                'ATL',
                'ATM',
                'AVC',
                'AWC',
                'B1P',
                'B7C',
                'B8H',
                'B8K',
                'B8N',
                'B8Q',
                'B8T',
                'B8W',
                'B9B',
                'B9H',
                'BGH',
                'BGM',
                'BMN',
                'BMP',
                'BMQ',
                'BOE',
                'BRU',
                'BT5',
                'BVP',
                'BZG',
                'C',
                'C25',
                'C2L',
                'C2S',
                'C31',
                'C32',
                'C34',
                'C36',
                'C37',
                'C38',
                'C42',
                'C43',
                'C45',
                'C46',
                'C49',
                'C4J',
                'C4S',
                'C5L',
                'C6G',
                'C7R',
                'C7S',
                'CB2',
                'CBR',
                'CBV',
                'CCC',
                'CDW',
                'CFL',
                'CFZ',
                'CG1',
                'CGY',
                'CH',
                'CJ1',
                'CM0',
                'CMR',
                'CNU',
                'CP1',
                'CS8',
                'CSF',
                'CSL',
                'CSM',
                'CTG',
                'CVC',
                'CX2',
                'D00',
                'D1P',
                'D33',
                'D3N',
                'D3T',
                'D4B',
                'D4M',
                'DA',
                'DBM',
                'DC',
                'DCG',
                'DCT',
                'DCZ',
                'DDG',
                'DDN',
                'DDX',
                'DFC',
                'DFG',
                'DG',
                'DG8',
                'DGI',
                'DHU',
                'DI',
                'DJF',
                'DN',
                'DNR',
                'DOC',
                'DP',
                'DPB',
                'DPY',
                'DRM',
                'DRP',
                'DRT',
                'DRZ',
                'DT',
                'DU',
                'DUZ',
                'DX',
                'DXD',
                'DXN',
                'DZ',
                'DZM',
                'E1X',
                'E3C',
                'E6G',
                'E7G',
                'EAN',
                'EDA',
                'EDC',
                'EDI',
                'EHG',
                'EIT',
                'ENA',
                'ENP',
                'ENQ',
                'EQ4',
                'EXC',
                'F2T',
                'F3H',
                'F3N',
                'F3O',
                'F4H',
                'F4Q',
                'F5H',
                'F6H',
                'F74',
                'F7H',
                'F7K',
                'FA2',
                'FA5',
                'FAG',
                'FAI',
                'FAX',
                'FDG',
                'FFD',
                'FHU',
                'FMG',
                'FMU',
                'FNU',
                'FOX',
                'G',
                'G25',
                'G2L',
                'G2S',
                'G31',
                'G32',
                'G33',
                'G35',
                'G36',
                'G38',
                'G42',
                'G46',
                'G47',
                'G48',
                'G49',
                'G4P',
                'G7M',
                'GAO',
                'GCK',
                'GDO',
                'GDR',
                'GF2',
                'GFL',
                'GH3',
                'GMS',
                'GMU',
                'GMX',
                'GNE',
                'GOM',
                'GRB',
                'GSR',
                'GSS',
                'GX1',
                'H2U',
                'HDP',
                'HEU',
                'HN0',
                'HN1',
                'HOL',
                'I',
                'I4U',
                'I5C',
                'IC',
                'IG',
                'IGU',
                'IMC',
                'IPN',
                'IRN',
                'IU',
                'JDT',
                'JLN',
                'JMH',
                'JSP',
                'JW5',
                'KAG',
                'KAK',
                'KGV',
                'LC',
                'LCA',
                'LCC',
                'LCG',
                'LCH',
                'LG',
                'LGP',
                'LHH',
                'LHO',
                'LHU',
                'LKC',
                'LMS',
                'LSH',
                'LST',
                'LTP',
                'LV2',
                'LWM',
                'M1G',
                'M1Y',
                'M2G',
                'M3O',
                'M4C',
                'M5M',
                'M7A',
                'MA6',
                'MA7',
                'MAD',
                'MCY',
                'MDJ',
                'MDK',
                'MDQ',
                'MDR',
                'MDU',
                'MDV',
                'ME6',
                'MEP',
                'MF7',
                'MFO',
                'MFT',
                'MG1',
                'MGQ',
                'MGV',
                'MHG',
                'MIA',
                'MM7',
                'MMT',
                'MNU',
                'MRG',
                'MTR',
                'MTU',
                'MUM',
                'N',
                'N4S',
                'N5I',
                'N5M',
                'N6G',
                'NCU',
                'NCX',
                'NDN',
                'NDU',
                'NF2',
                'NMS',
                'NMT',
                'NP3',
                'NR1',
                'NRI',
                'NTT',
                'NYM',
                'O2C',
                'O2G',
                'O2Z',
                'OAD',
                'ODP',
                'OGX',
                'OHU',
                'OIP',
                'OKN',
                'OKQ',
                'OKT',
                'OMC',
                'OMG',
                'OMU',
                'ONE',
                'OOB',
                'OYW',
                'P',
                'P1P',
                'P2T',
                'P2U',
                'P4U',
                'P5P',
                'P6D',
                'P7G',
                'P9G',
                'PBT',
                'PDU',
                'PG7',
                'PGN',
                'PGP',
                'PMT',
                'PPU',
                'PPW',
                'PQ1',
                'PR5',
                'PRN',
                'PST',
                'PSU',
                'PU',
                'PUY',
                'PVX',
                'PYO',
                'PYY',
                'PZG',
                'QA7',
                'QBT',
                'QUO',
                'RBD',
                'RCE',
                'RDG',
                'RFJ',
                'RIA',
                'RMP',
                'RPC',
                'RSP',
                'RSQ',
                'RT',
                'RTP',
                'RUS',
                'RY',
                'S2M',
                'S4A',
                'S4C',
                'S4G',
                'S4U',
                'S6G',
                'S8M',
                'S9L',
                'SAY',
                'SDE',
                'SDG',
                'SDH',
                'SMP',
                'SMT',
                'SOS',
                'SPT',
                'SRA',
                'SSU',
                'SUR',
                'T',
                'T0T',
                'T23',
                'T2S',
                'T2T',
                'T31',
                'T32',
                'T36',
                'T37',
                'T38',
                'T39',
                'T3P',
                'T41',
                'T48',
                'T49',
                'T4S',
                'T5O',
                'T5S',
                'T64',
                'T6A',
                'TA3',
                'TAF',
                'TAL',
                'TC',
                'TC1',
                'TCJ',
                'TCP',
                'TCY',
                'TDY',
                'TED',
                'TFE',
                'TFF',
                'TFO',
                'TFT',
                'TG',
                'TGP',
                'THM',
                'THP',
                'THX',
                'TLB',
                'TLC',
                'TLN',
                'TP1',
                'TPC',
                'TPG',
                'TSP',
                'TT',
                'TTD',
                'TTI',
                'TTM',
                'TX2',
                'TYU',
                'U',
                'U23',
                'U25',
                'U2L',
                'U2N',
                'U2P',
                'U31',
                'U33',
                'U34',
                'U36',
                'U37',
                'U4M',
                'U5M',
                'U8U',
                'UAR',
                'UBD',
                'UBI',
                'UBR',
                'UCL',
                'UD5',
                'UDP',
                'UF2',
                'UFB',
                'UFP',
                'UFR',
                'UFT',
                'UMS',
                'UMX',
                'UOA',
                'UOB',
                'UPE',
                'UPS',
                'UPV',
                'UR3',
                'URD',
                'URT',
                'URU',
                'URX',
                'US1',
                'US2',
                'US3',
                'US4',
                'US5',
                'USM',
                'UVX',
                'UY1',
                'UY4',
                'V3L',
                'VET',
                'X',
                'X4A',
                'XAD',
                'XAE',
                'XAL',
                'XAR',
                'XCL',
                'XCR',
                'XCS',
                'XCT',
                'XCY',
                'XGA',
                'XGL',
                'XGR',
                'XGU',
                'XPB',
                'XTF',
                'XTH',
                'XTL',
                'XTR',
                'XTS',
                'XTY',
                'XUA',
                'XUG',
                'Y5P',
                'YCO',
                'YG',
                'YRR',
                'YYG',
                'Z',
                'ZBC',
                'ZBU',
                'ZDU']
    return na_codes


def amino_acid_codes():
    aa_codes = ['000',
                '004',
                '005',
                '00B',
                '00C',
                '00D',
                '00E',
                '00M',
                '00O',
                '01N',
                '01W',
                '02A',
                '02K',
                '02L',
                '02O',
                '02V',
                '02Y',
                '037',
                '03E',
                '03Y',
                '04R',
                '04U',
                '04V',
                '04X',
                '05N',
                '060',
                '07O',
                '08M',
                '08P',
                '0A0',
                '0A1',
                '0A2',
                '0A8',
                '0A9',
                '0AA',
                '0AB',
                '0AC',
                '0AF',
                '0AG',
                '0AH',
                '0AK',
                '0AR',
                '0AY',
                '0AZ',
                '0BN',
                '0CS',
                '0E5',
                '0EA',
                '0EH',
                '0FL',
                '0G5',
                '0GG',
                '0JT',
                '0LF',
                '0MU',
                '0NC',
                '0PR',
                '0QL',
                '0QZ',
                '0RJ',
                '0TD',
                '0TH',
                '0UZ',
                '0W6',
                '0WZ',
                '0X9',
                '0XL',
                '0XO',
                '0XQ',
                '0Y8',
                '0Y9',
                '0YG',
                '11W',
                '12L',
                '12X',
                '12Y',
                '13E',
                '175',
                '192',
                '193',
                '19W',
                '1AC',
                '1C3',
                '1E3',
                '1G1',
                '1G2',
                '1G3',
                '1G5',
                '1G6',
                '1G8',
                '1HB',
                '1HD',
                '1IP',
                '1JM',
                '1L1',
                '1ME',
                '1MH',
                '1OP',
                '1PA',
                '1PI',
                '1TQ',
                '1TX',
                '1TY',
                '1U8',
                '1VR',
                '1X6',
                '1XW',
                '1Y0',
                '1ZN',
                '200',
                '22G',
                '23F',
                '23P',
                '23S',
                '26B',
                '28J',
                '28X',
                '2AD',
                '2AG',
                '2AO',
                '2CO',
                '2FM',
                '2GX',
                '2HF',
                '2JC',
                '2JF',
                '2JG',
                '2JH',
                '2JJ',
                '2JN',
                '2KK',
                '2KP',
                '2KY',
                '2KZ',
                '2L5',
                '2L6',
                '2L9',
                '2LT',
                '2LU',
                '2ML',
                '2MR',
                '2MT',
                '2OR',
                '2P0',
                '2PI',
                '2QD',
                '2QY',
                '2QZ',
                '2R1',
                '2R3',
                '2RA',
                '2RX',
                '2SO',
                '2TL',
                '2TY',
                '2VA',
                '2XA',
                '2YC',
                '2YF',
                '2YG',
                '2YH',
                '2YJ',
                '2ZC',
                '30F',
                '30V',
                '31Q',
                '32L',
                '32S',
                '32T',
                '33S',
                '33W',
                '33X',
                '34E',
                '35Y',
                '39S',
                '3A5',
                '3AH',
                '3AR',
                '3BY',
                '3CF',
                '3CT',
                '3EG',
                '3FG',
                '3GA',
                '3GL',
                '3K4',
                '3MD',
                '3MM',
                '3MY',
                '3NF',
                '3O3',
                '3PM',
                '3PX',
                '3QN',
                '3TY',
                '3WS',
                '3WT',
                '3WU',
                '3WX',
                '3X9',
                '3XH',
                '3YM',
                '3ZH',
                '3ZL',
                '41H',
                '41Q',
                '432',
                '45W',
                '4AF',
                '4AK',
                '4AR',
                '4AW',
                '4CF',
                '4CG',
                '4CY',
                '4D4',
                '4DB',
                '4DP',
                '4F3',
                '4FB',
                '4FO',
                '4FW',
                '4GJ',
                '4HH',
                '4HJ',
                '4HL',
                '4HT',
                '4II',
                '4IK',
                '4IN',
                '4J2',
                '4J4',
                '4J5',
                '4KY',
                '4L0',
                '4L8',
                '4LZ',
                '4M8',
                '4MM',
                '4N3',
                '4N7',
                '4N8',
                '4N9',
                '4NT',
                '4NU',
                '4OG',
                '4OP',
                '4OU',
                '4OV',
                '4OZ',
                '4PH',
                '4PQ',
                '4QK',
                '4SJ',
                '4U7',
                '4UD',
                '4WQ',
                '51T',
                '54C',
                '562',
                '56C',
                '5AB',
                '5CR',
                '5CS',
                '5CT',
                '5CW',
                '5DW',
                '5FQ',
                '5GG',
                '5GM',
                '5HP',
                '5LB',
                '5LE',
                '5LF',
                '5LG',
                '5LH',
                '5LJ',
                '5MW',
                '5OH',
                '5OL',
                '5OM',
                '5OW',
                '5PG',
                '5R5',
                '5SQ',
                '5T3',
                '5VV',
                '5X8',
                '5XU',
                '5ZA',
                '60F',
                '62H',
                '66C',
                '66D',
                '66E',
                '6BR',
                '6CL',
                '6CV',
                '6CW',
                '6DN',
                '6DU',
                '6E4',
                '6FL',
                '6G4',
                '6GL',
                '6HN',
                '6KM',
                '6KY',
                '6M6',
                '6RK',
                '6V1',
                '6V9',
                '6WK',
                '6Y9',
                '6ZS',
                '73C',
                '73N',
                '73O',
                '73P',
                '74P',
                '75A',
                '7C9',
                '7HA',
                '7JA',
                '7MN',
                '7N8',
                '7O5',
                '7XC',
                '7YL',
                '7YO',
                '81R',
                '81S',
                '823',
                '85F',
                '85G',
                '85J',
                '8JB',
                '8LJ',
                '8RE',
                '8SP',
                '8WY',
                '8YR',
                '999',
                '99Y',
                '9AT',
                '9DN',
                '9DS',
                '9E7',
                '9EV',
                '9KK',
                '9KP',
                '9MN',
                '9NE',
                '9NF',
                '9NR',
                '9NV',
                '9R1',
                '9R4',
                '9R7',
                '9TR',
                '9TU',
                '9TX',
                '9U0',
                '9U6',
                '9U9',
                '9UC',
                '9UF',
                '9V0',
                '9V6',
                '9VC',
                '9VF',
                '9VL',
                '9VR',
                'A0G',
                'A5N',
                'A66',
                'A6I',
                'A89',
                'A8E',
                'A9D',
                'AA3',
                'AA4',
                'AA6',
                'AAR',
                'AB7',
                'ABA',
                'AC5',
                'ACB',
                'ACL',
                'AE5',
                'AEI',
                'AFA',
                'AGD',
                'AGM',
                'AGQ',
                'AGT',
                'AHB',
                'AHO',
                'AHP',
                'AIB',
                'AJE',
                'AKL',
                'ALA',
                'ALC',
                'ALM',
                'ALN',
                'ALO',
                'ALS',
                'ALY',
                'AN6',
                'AN8',
                'APH',
                'API',
                'APK',
                'APM',
                'APO',
                'APP',
                'AR2',
                'AR4',
                'ARG',
                'ARM',
                'ARV',
                'AS2',
                'AS7',
                'AS9',
                'ASA',
                'ASB',
                'ASI',
                'ASK',
                'ASL',
                'ASM',
                'ASN',
                'ASP',
                'ASQ',
                'ASX',
                'AVN',
                'AYA',
                'AYG',
                'AZH',
                'AZK',
                'AZS',
                'AZY',
                'B1F',
                'B26',
                'B27',
                'B2A',
                'B2C',
                'B2F',
                'B2H',
                'B2I',
                'B2N',
                'B2V',
                'B3A',
                'B3D',
                'B3E',
                'B3K',
                'B3L',
                'B3M',
                'B3Q',
                'B3S',
                'B3T',
                'B3U',
                'B3X',
                'B3Y',
                'B8R',
                'BAL',
                'BB6',
                'BB7',
                'BB8',
                'BB9',
                'BBC',
                'BCC',
                'BCS',
                'BCX',
                'BF6',
                'BF7',
                'BF9',
                'BFD',
                'BG1',
                'BH2',
                'BHD',
                'BIF',
                'BIL',
                'BIU',
                'BJO',
                'BL2',
                'BLE',
                'BLY',
                'BMT',
                'BNN',
                'BNO',
                'BOR',
                'BP5',
                'BPE',
                'BSE',
                'BTA',
                'BTC',
                'BTK',
                'BUC',
                'BUG',
                'BW5',
                'BWB',
                'BWV',
                'BXT',
                'BYR',
                'BZK',
                'C0O',
                'C12',
                'C1T',
                'C1X',
                'C22',
                'C2N',
                'C3Y',
                'C4R',
                'C5C',
                'C66',
                'C6C',
                'C99',
                'CAB',
                'CAF',
                'CAL',
                'CAS',
                'CAV',
                'CCL',
                'CCS',
                'CCY',
                'CDE',
                'CDV',
                'CE7',
                'CEA',
                'CFY',
                'CG6',
                'CGA',
                'CGH',
                'CGU',
                'CGV',
                'CH6',
                'CH7',
                'CHF',
                'CHG',
                'CHP',
                'CHS',
                'CIR',
                'CJO',
                'CLB',
                'CLD',
                'CLE',
                'CLG',
                'CLH',
                'CLV',
                'CME',
                'CMH',
                'CML',
                'CMT',
                'CNG',
                'CPC',
                'CPI',
                'CQ1',
                'CQ2',
                'CR0',
                'CR2',
                'CR5',
                'CR7',
                'CR8',
                'CRF',
                'CRG',
                'CRK',
                'CRO',
                'CRQ',
                'CRU',
                'CRW',
                'CRX',
                'CS0',
                'CS1',
                'CS3',
                'CS4',
                'CSA',
                'CSB',
                'CSD',
                'CSE',
                'CSH',
                'CSJ',
                'CSK',
                'CSO',
                'CSP',
                'CSR',
                'CSS',
                'CSU',
                'CSW',
                'CSX',
                'CSY',
                'CSZ',
                'CTE',
                'CTH',
                'CUC',
                'CUD',
                'CWD',
                'CWR',
                'CXM',
                'CY0',
                'CY1',
                'CY3',
                'CY4',
                'CYA',
                'CYD',
                'CYF',
                'CYG',
                'CYJ',
                'CYM',
                'CYQ',
                'CYR',
                'CYS',
                'CYW',
                'CZ2',
                'CZO',
                'CZS',
                'CZZ',
                'D0Q',
                'D11',
                'D2T',
                'D3P',
                'D4P',
                'DA2',
                'DAB',
                'DAH',
                'DAL',
                'DAM',
                'DAR',
                'DAS',
                'DBB',
                'DBS',
                'DBU',
                'DBY',
                'DBZ',
                'DC2',
                'DCY',
                'DDE',
                'DDZ',
                'DFF',
                'DFI',
                'DFO',
                'DGH',
                'DGL',
                'DGN',
                'DHA',
                'DHI',
                'DHL',
                'DHN',
                'DHP',
                'DHV',
                'DI7',
                'DI8',
                'DIL',
                'DIR',
                'DIV',
                'DJD',
                'DLE',
                'DLS',
                'DLY',
                'DM0',
                'DMH',
                'DMK',
                'DMT',
                'DNE',
                'DNG',
                'DNL',
                'DNM',
                'DNP',
                'DNS',
                'DNW',
                'DO2',
                'DOH',
                'DON',
                'DPL',
                'DPN',
                'DPP',
                'DPQ',
                'DPR',
                'DSE',
                'DSG',
                'DSN',
                'DSP',
                'DTH',
                'DTR',
                'DTY',
                'DV7',
                'DVA',
                'DYA',
                'DYG',
                'DYJ',
                'DYL',
                'DYS',
                'E03',
                'E0Y',
                'E95',
                'E9C',
                'E9M',
                'E9V',
                'ECC',
                'ECX',
                'EEP',
                'EFC',
                'EJA',
                'ELY',
                'EME',
                'EO2',
                'EOE',
                'ESB',
                'ETA',
                'EUP',
                'EXA',
                'EXY',
                'EYG',
                'F0G',
                'F2F',
                'F2Y',
                'F3M',
                'F3T',
                'F6N',
                'F75',
                'F7P',
                'F7Q',
                'F7S',
                'F7V',
                'F7W',
                'F93',
                'F9D',
                'FAK',
                'FB5',
                'FB6',
                'FC0',
                'FCL',
                'FDL',
                'FF9',
                'FFM',
                'FGA',
                'FGL',
                'FGP',
                'FH7',
                'FHE',
                'FHL',
                'FHO',
                'FIO',
                'FL6',
                'FLA',
                'FLE',
                'FME',
                'FOD',
                'FOE',
                'FP9',
                'FPK',
                'FPR',
                'FQA',
                'FRD',
                'FT6',
                'FTR',
                'FTY',
                'FVA',
                'FY2',
                'FY3',
                'FZN',
                'G01',
                'G3M',
                'G5G',
                'G8M',
                'GAU',
                'GEE',
                'GFT',
                'GGL',
                'GHC',
                'GHG',
                'GHP',
                'GHW',
                'GLH',
                'GLJ',
                'GLM',
                'GLN',
                'GLQ',
                'GLU',
                'GLX',
                'GLY',
                'GLZ',
                'GMA',
                'GME',
                'GMO',
                'GNC',
                'GND',
                'GPL',
                'GSC',
                'GSU',
                'GT9',
                'GVL',
                'GYC',
                'GYS',
                'GZB',
                'GZJ',
                'H14',
                'H5M',
                'HAC',
                'HAR',
                'HBN',
                'HCL',
                'HCM',
                'HCS',
                'HFA',
                'HG7',
                'HGL',
                'HGM',
                'HGY',
                'HHI',
                'HIA',
                'HIC',
                'HIP',
                'HIQ',
                'HIS',
                'HIX',
                'HJH',
                'HJV',
                'HJY',
                'HL2',
                'HL5',
                'HLU',
                'HLX',
                'HLY',
                'HM8',
                'HM9',
                'HMF',
                'HMR',
                'HNC',
                'HOO',
                'HOX',
                'HPC',
                'HPE',
                'HPQ',
                'HQA',
                'HR7',
                'HRG',
                'HRP',
                'HS8',
                'HS9',
                'HSE',
                'HSK',
                'HSL',
                'HSO',
                'HSV',
                'HT7',
                'HTI',
                'HTN',
                'HTR',
                'HTY',
                'HV5',
                'HVA',
                'HY3',
                'HYP',
                'HZP',
                'I1C',
                'I2M',
                'I4G',
                'I58',
                'IAM',
                'IAR',
                'IAS',
                'ICY',
                'IEL',
                'IEY',
                'IGL',
                'IIC',
                'IIL',
                'ILE',
                'ILG',
                'ILM',
                'ILX',
                'IML',
                'IOR',
                'IOY',
                'IT1',
                'IYR',
                'IYT',
                'IZO',
                'J3D',
                'J7H',
                'J8W',
                'J9A',
                'J9Y',
                'JBY',
                'JJJ',
                'JJK',
                'JJL',
                'JKH',
                'JLP',
                'K1R',
                'K5H',
                'K5L',
                'KBE',
                'KBS',
                'KBV',
                'KCJ',
                'KCR',
                'KCX',
                'KCY',
                'KEO',
                'KFP',
                'KGC',
                'KHB',
                'KJW',
                'KKD',
                'KNB',
                'KOR',
                'KPF',
                'KPI',
                'KPY',
                'KST',
                'KWS',
                'KXV',
                'KY4',
                'KY7',
                'KYN',
                'KYQ',
                'KZ1',
                'KZ4',
                'KZ7',
                'KZG',
                'KZV',
                'KZY',
                'L2A',
                'L3O',
                'L5P',
                'LA2',
                'LAA',
                'LAL',
                'LAY',
                'LBY',
                'LBZ',
                'LCK',
                'LCX',
                'LDH',
                'LE1',
                'LED',
                'LEF',
                'LEH',
                'LEI',
                'LEM',
                'LEN',
                'LEP',
                'LET',
                'LEU',
                'LGY',
                'LHC',
                'LHV',
                'LLO',
                'LLP',
                'LLY',
                'LLZ',
                'LME',
                'LMF',
                'LMQ',
                'LNE',
                'LNM',
                'LNT',
                'LOU',
                'LP6',
                'LPD',
                'LPG',
                'LPH',
                'LPS',
                'LRK',
                'LSO',
                'LTA',
                'LTR',
                'LV8',
                'LVG',
                'LVN',
                'LWY',
                'LYF',
                'LYH',
                'LYM',
                'LYN',
                'LYO',
                'LYR',
                'LYS',
                'LYU',
                'LYV',
                'LYX',
                'LYZ',
                'M0H',
                'M2L',
                'M2S',
                'M30',
                'M3L',
                'M3R',
                'M3V',
                'M64',
                'M6J',
                'M6M',
                'M6Y',
                'M9G',
                'MA',
                'MAA',
                'MAI',
                'MBQ',
                'MC1',
                'MCG',
                'MCL',
                'MCS',
                'MD0',
                'MD3',
                'MD5',
                'MD6',
                'MDF',
                'MDH',
                'MDO',
                'ME0',
                'MEA',
                'MED',
                'MEG',
                'MEN',
                'MEQ',
                'MET',
                'MEU',
                'MF3',
                'MFC',
                'MFV',
                'MGG',
                'MGN',
                'MGY',
                'MH1',
                'MH6',
                'MH8',
                'MHE',
                'MHL',
                'MHO',
                'MHS',
                'MHU',
                'MHV',
                'MHW',
                'MHY',
                'MIR',
                'MIS',
                'MJ1',
                'MJS',
                'MK8',
                'MKD',
                'ML3',
                'MLE',
                'MLL',
                'MLU',
                'MLY',
                'MLZ',
                'MME',
                'MMO',
                'MND',
                'MNL',
                'MNV',
                'MOD',
                'MOZ',
                'MP4',
                'MP8',
                'MPH',
                'MPJ',
                'MPQ',
                'MSE',
                'MSL',
                'MSO',
                'MSP',
                'MT2',
                'MTY',
                'MV9',
                'MVA',
                'MYK',
                'MYN',
                'N0A',
                'N10',
                'N2C',
                'N65',
                'N7P',
                'N80',
                'N8P',
                'N9P',
                'NA8',
                'NAL',
                'NAM',
                'NB8',
                'NBQ',
                'NC1',
                'NCB',
                'NCY',
                'NDF',
                'NEM',
                'NEP',
                'NFA',
                'NHL',
                'NIT',
                'NIY',
                'NKS',
                'NLB',
                'NLE',
                'NLN',
                'NLO',
                'NLP',
                'NLQ',
                'NLW',
                'NLY',
                'NMC',
                'NME',
                'NMM',
                'NNH',
                'NOT',
                'NPH',
                'NPI',
                'NRP',
                'NRQ',
                'NSK',
                'NTR',
                'NTY',
                'NVA',
                'NWD',
                'NYB',
                'NYC',
                'NYG',
                'NYS',
                'NZC',
                'NZH',
                'O12',
                'O7A',
                'O7D',
                'O7G',
                'OAS',
                'OBF',
                'OBS',
                'OCS',
                'OCY',
                'ODA',
                'ODS',
                'OEM',
                'OFM',
                'OHD',
                'OHI',
                'OHS',
                'OIC',
                'OIM',
                'OJY',
                'OK4',
                'OLD',
                'OLE',
                'OLZ',
                'OMH',
                'OMT',
                'OMX',
                'OMY',
                'OMZ',
                'ONH',
                'ONL',
                'ORD',
                'ORN',
                'ORQ',
                'OSE',
                'OTH',
                'OTY',
                'OTZ',
                'OV7',
                'OXX',
                'OYL',
                'OZT',
                'OZW',
                'P0A',
                'P1L',
                'P2Q',
                'P2Y',
                'P3Q',
                'P4E',
                'P4F',
                'P9S',
                'PAQ',
                'PAS',
                'PAT',
                'PBB',
                'PBF',
                'PCA',
                'PCC',
                'PCE',
                'PCS',
                'PDD',
                'PDL',
                'PDW',
                'PE1',
                'PEC',
                'PF5',
                'PFF',
                'PFX',
                'PG1',
                'PG9',
                'PGL',
                'PGY',
                'PH6',
                'PH8',
                'PHA',
                'PHD',
                'PHE',
                'PHI',
                'PHL',
                'PHM',
                'PIA',
                'PLE',
                'PLJ',
                'PM3',
                'PNZ',
                'POK',
                'POM',
                'PPN',
                'PQ4',
                'PQG',
                'PR3',
                'PR4',
                'PR7',
                'PR9',
                'PRJ',
                'PRK',
                'PRO',
                'PRQ',
                'PRR',
                'PRS',
                'PRV',
                'PSH',
                'PSS',
                'PSW',
                'PTA',
                'PTH',
                'PTM',
                'PTR',
                'PVH',
                'PVL',
                'PVO',
                'PXU',
                'PXZ',
                'PYA',
                'PYH',
                'PYL',
                'PYX',
                'Q3P',
                'QAC',
                'QC4',
                'QCA',
                'QCD',
                'QCS',
                'QDS',
                'QFG',
                'QIL',
                'QLG',
                'QMM',
                'QNY',
                'QPA',
                'QPH',
                'QXV',
                'QYG',
                'QZA',
                'R0E',
                'R1A',
                'R2P',
                'R2T',
                'R4K',
                'R6E',
                'RC7',
                'RE0',
                'RE3',
                'RF9',
                'RGL',
                'RPI',
                'RT0',
                'RVJ',
                'RVX',
                'RZ4',
                'S12',
                'S2C',
                'S2D',
                'S2P',
                'SAC',
                'SAH',
                'SAO',
                'SAR',
                'SBD',
                'SBL',
                'SCH',
                'SCS',
                'SCY',
                'SD2',
                'SD4',
                'SDP',
                'SE7',
                'SEB',
                'SEC',
                'SEE',
                'SEG',
                'SEL',
                'SEM',
                'SEN',
                'SEP',
                'SER',
                'SET',
                'SFE',
                'SGB',
                'SHC',
                'SHP',
                'SHR',
                'SIB',
                'SIC',
                'SIN',
                'SKG',
                'SKH',
                'SKJ',
                'SLL',
                'SLR',
                'SLZ',
                'SMC',
                'SME',
                'SMF',
                'SNC',
                'SNN',
                'SOC',
                'SOY',
                'SRZ',
                'STA',
                'STY',
                'SUB',
                'SUI',
                'SUN',
                'SVA',
                'SVV',
                'SVW',
                'SVX',
                'SVY',
                'SVZ',
                'SWG',
                'SXE',
                'SYS',
                'T0I',
                'T11',
                'T66',
                'T8L',
                'T9E',
                'TA4',
                'TAV',
                'TBG',
                'TBM',
                'TCQ',
                'TCR',
                'TDD',
                'TDF',
                'TEF',
                'TFQ',
                'TFR',
                'TGH',
                'TH5',
                'TH6',
                'THC',
                'THO',
                'THR',
                'THZ',
                'TIH',
                'TIS',
                'TLY',
                'TMB',
                'TMD',
                'TNB',
                'TNQ',
                'TNR',
                'TNY',
                'TOQ',
                'TOX',
                'TOZ',
                'TPH',
                'TPJ',
                'TPK',
                'TPL',
                'TPO',
                'TPQ',
                'TQI',
                'TQQ',
                'TQZ',
                'TRF',
                'TRG',
                'TRN',
                'TRO',
                'TRP',
                'TRQ',
                'TRW',
                'TRX',
                'TRY',
                'TS9',
                'TSQ',
                'TST',
                'TSY',
                'TTQ',
                'TTS',
                'TXY',
                'TY1',
                'TY2',
                'TY3',
                'TY5',
                'TY8',
                'TY9',
                'TYB',
                'TYE',
                'TYI',
                'TYJ',
                'TYN',
                'TYO',
                'TYQ',
                'TYR',
                'TYS',
                'TYT',
                'TYX',
                'TYY',
                'TZB',
                'TZO',
                'U2X',
                'U3X',
                'U6A',
                'UAL',
                'UB4',
                'UDS',
                'UF0',
                'UGY',
                'UM1',
                'UM2',
                'UMA',
                'UN1',
                'UN2',
                'UNK',
                'UOX',
                'UU4',
                'UU5',
                'UXY',
                'UZ4',
                'UZA',
                'V1V',
                'VAD',
                'VAF',
                'VAH',
                'VAL',
                'VAS',
                'VB1',
                'VDL',
                'VH0',
                'VLL',
                'VLM',
                'VME',
                'VMS',
                'VOL',
                'VR0',
                'WCR',
                'WFP',
                'WLU',
                'WPA',
                'WRP',
                'WVL',
                'X2W',
                'X9Q',
                'XCN',
                'XDT',
                'XOK',
                'XPC',
                'XPL',
                'XPR',
                'XSN',
                'XW1',
                'XX1',
                'XXA',
                'XXY',
                'XYC',
                'XYG',
                'Y28',
                'YCM',
                'YCP',
                'YNM',
                'YPR',
                'YPZ',
                'YTH',
                'YYA',
                'Z01',
                'Z3E',
                'Z70',
                'ZAE',
                'ZAL',
                'ZBZ',
                'ZCL',
                'ZFB',
                'ZGL',
                'ZIQ',
                'ZS8',
                'ZU0',
                'ZUK',
                'ZXX',
                'ZYJ',
                'ZYK',
                'ZZD',
                'ZZJ',
                'ZZU']
    return aa_codes
